﻿/******************************************************************************
 * File Name			: BooleanToVisibilityConverter.cs
 * Author				: Ramesh Jallepalli
 * Date of Creation		: 23/03/2014
 * Comments     		: Class to convert boolean to visible and string to color 
 * ____________________________________________________________________________
 *****************************************************************************/
using System;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using System.Windows.Media;

namespace DataContextDemo.Common
{
    /// <summary>
    /// Value converter that translates true to <see cref="Visibility.Visible"/> and false to
    /// <see cref="Visibility.Collapsed"/>.
    /// </summary>
    public sealed class BooleanToVisibilityConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return (value is bool && (bool)value) ? Visibility.Visible : Visibility.Collapsed;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value is Visibility && (Visibility)value == Visibility.Visible;
        }
    }
    /// <summary>
    /// Value converter that translates string to Color
    /// </summary>
    public sealed class StringToEllipseBackGroundColorConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            switch ((string)value)
            {
                case "Idle": return Brushes.Gray;
                case "Initializing": return Brushes.Purple;
                case "Running": return Brushes.Blue;
                case "Passed": return Brushes.Green;
                case "PASS": return Brushes.Green;
                case "Failed": return Brushes.DarkRed;
                case "FAIL": return Brushes.DarkRed;
                case "NotRunning": return Brushes.Gray;
                case "Cancel": return Brushes.DarkRed;
                case "Pause": return Brushes.Gold;
                default: return Brushes.Gray;
            }
        }
        public object ConvertBack(object value, Type targetType,
               object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
    /// <summary>
    /// Value converter that translates string to Color
    /// </summary>
    public sealed class StringToGridBackGroundColorConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            switch ((string)value)
            {
                case "Idle": return Brushes.SkyBlue;
                case "Initializing": return Brushes.SkyBlue;
                case "Running": return Brushes.SkyBlue;
                case "Passed": return Brushes.LimeGreen;
                case "PASS": return Brushes.LimeGreen;
                case "Failed": return Brushes.Red;
                case "FAIL": return Brushes.Red;
                case "NotRunning": return Brushes.LightGray;
                case "Cancel": return Brushes.Red;
                case "Pause": return Brushes.SkyBlue;
                default: return Brushes.SkyBlue;
            }
        }
        public object ConvertBack(object value, Type targetType,
               object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
    /// <summary>
    /// Value converter that translates string to Color
    /// </summary>
    public sealed class StringToTelentBackGroundColorConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            switch ((string)value)
            {
                case "White": return Brushes.White;
                case "Black": return Brushes.Black;
                case "Yellow": return Brushes.Yellow;
                case "Green": return Brushes.LawnGreen;
                default: return Brushes.LawnGreen;
            }
        }
        public object ConvertBack(object value, Type targetType,
               object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
    /// <summary>
    /// Value converter that translates string to Color
    /// </summary>
    public sealed class StringToGridBackGroundColorConverterForGenApp : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            switch ((string)value)
            {
                case "Idle": return Brushes.SkyBlue;
                case "Initializing": return Brushes.SkyBlue;
                case "Running": return Brushes.SkyBlue;
                case "Passed": return Brushes.LimeGreen;
                case "PASS": return Brushes.LimeGreen;
                case "Failed": return Brushes.Red;
                case "FAIL": return Brushes.Red;
                case "NotRunning": return Brushes.LightGray;
                case "Cancel": return Brushes.Red;
                case "Pause": return Brushes.SkyBlue;
                default: return Brushes.SkyBlue;
            }
        }
        public object ConvertBack(object value, Type targetType,
               object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
    /// <summary>
    /// Value converter that translates string to Color
    /// </summary>
    public sealed class StringToEllipseBackGroundColorConverterForGenApp : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            switch ((string)value)
            {
                case "Idle": return Brushes.Gray;
                case "Initializing": return Brushes.Purple;
                case "Running": return Brushes.Blue;
                case "Passed": return Brushes.Green;
                case "PASS": return Brushes.Green;
                case "Failed": return Brushes.DarkRed;
                case "FAIL": return Brushes.DarkRed;
                case "NotRunning":  firstColor = Color.FromRgb(66, 67, 69);
                     secColor = Color.FromRgb(144, 145, 140);
                    thirdColor = Color.FromRgb(225, 227, 226);
                    return setEllipseColor(firstColor, secColor, thirdColor);
                case "Cancel": return Brushes.DarkRed;
                case "Pause": return Brushes.Gold;
                case "MultiMode":
                    firstColor = Color.FromRgb(49, 94, 237);
                    secColor = Color.FromRgb(140, 169, 249);
                    thirdColor = Color.FromRgb(235, 238, 253);
               return setEllipseColor(firstColor, secColor, thirdColor);
                default: return Brushes.Gray;
            }
        }
        public object ConvertBack(object value, Type targetType,
               object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
        private LinearGradientBrush setEllipseColor(Color fisrtColor, Color secondColor, Color thirdColor)
        {
            LinearGradientBrush fiveColorLGB = new LinearGradientBrush();
            fiveColorLGB.StartPoint = new Point(0, 1);
            fiveColorLGB.EndPoint = new Point(0, 0);
            GradientStop firstGS = new GradientStop();
            firstGS.Color = fisrtColor;
            firstGS.Offset = 0.6;
            fiveColorLGB.GradientStops.Add(firstGS);
            GradientStop secGS = new GradientStop();
            secGS.Color = secondColor;
            secGS.Offset = 0.3;
            fiveColorLGB.GradientStops.Add(secGS);
            GradientStop thirdGS = new GradientStop();
            thirdGS.Color = thirdColor;
            thirdGS.Offset = 0.1;
            fiveColorLGB.GradientStops.Add(thirdGS);
           return fiveColorLGB;
        }
        private Color firstColor { get; set; }
        private Color secColor { get; set; }
        private Color thirdColor { get; set; }
    }
}