﻿/******************************************************************************
 * File Name			: DelegateCommand.cs
 * Author				: Ramesh Jallepalli
 * Date of Creation		: 23/03/2014
 * Comments     		: Class to implement delegates and executes delegate events passed from various view models
 * ____________________________________________________________________________
 *****************************************************************************/
using System;
using System.Windows.Input;

namespace DataContextDemo.Common
{
    public class DelegateCommand<T> : ICommand where T : class
    {
        private readonly Predicate<T> _canExecute;
        private readonly Action<T> _execute;
        protected bool _isEnabled = true;

        public DelegateCommand(Action<T> execute, Predicate<T> canExecute = null)
        {
            _execute = execute;
            _canExecute = canExecute ?? (t => _isEnabled);
        }

        #region ICommand Members

        public bool CanExecute(object parameter)
        {
            return _canExecute((T)parameter);
        }

        public event EventHandler CanExecuteChanged;

        public void Execute(object parameter)
        {
            _execute((T)parameter);
        }

        #endregion

        public void RaiseCanExecuteChanged()
        {
            OnCanExecuteChanged();
        }

        protected virtual void OnCanExecuteChanged()
        {
            EventHandler handler = CanExecuteChanged;
            if (handler != null)
            {
                handler(this, EventArgs.Empty);
            }
        }
    }
}