﻿/******************************************************************************
 * File Name			: EventRaisingStreamWriter.cs
 * Author				: Ramesh Jallepalli
 * Date of Creation		: 23/03/2014
 * Comments     		: Class to implement stream of characters from object
 * ____________________________________________________________________________
 *****************************************************************************/
using System;
using System.IO;

namespace DataContextDemo.Common
{
    public class EventRaisingStreamWriter : StreamWriter
    {
        #region Event
        public event EventHandler<EvtArgs<string>> StringWritten;
        #endregion

        #region CTOR
        public EventRaisingStreamWriter(Stream s)
            : base(s)
        { }
        #endregion

        #region Private Methods
        private void LaunchEvent(string txtWritten)
        {
            if (StringWritten != null)
            {
                StringWritten(this, new EvtArgs<string>(txtWritten));
            }
        }
        #endregion

        #region Overrides

        public override void Write(string value)
        {
            base.Write(value);
            LaunchEvent(value);
        }
        public override void Write(bool value)
        {
            base.Write(value);
            LaunchEvent(value.ToString());
        }

        #endregion
    }
}