﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using DataContextDemo.Common;
using System.Windows.Controls;
using System.Windows;
using DatacontextDemo.XamlFiles;
using System.Diagnostics;
using System.Windows.Threading;
using System.Collections.ObjectModel;


namespace DatacontextDemo.ViewModel
{
    public class MainWindowViewModel : BaseWindowViewModel, IMainWindowViewModel
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainWindowViewModel"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        /// <param name="container">The container.</param>
        public MainWindowViewModel(IMainWindow view, StructureMap.IContainer container)
            : base(view, container)
        {
            GridLoaded = new DelegateCommand<object>(OnGridLoaded);
            onStartScript = new DelegateCommand<object>(onStartScriptCommand);
        }

        /// <summary>
        /// Gets or sets the grid loaded.
        /// </summary>
        /// <value>
        /// The grid loaded.
        /// </value>
        public DelegateCommand<object> GridLoaded { get; set; }

        /// <summary>
        /// Gets or sets the on start script.
        /// </summary>
        /// <value>
        /// The on start script.
        /// </value>
        public DelegateCommand<object> onStartScript { get; set; }

        /// <summary>
        /// Gets or sets the station grid.
        /// </summary>
        /// <value>
        /// The station grid.
        /// </value>
        public Grid StationGrid { get; set; }

        /// <summary>
        /// Gets or sets the text box count.
        /// </summary>
        /// <value>
        /// The text box count.
        /// </value>
        public ITextBoxControlViewModel textBoxCnt { get; set; }

        /// <summary>
        /// Called when [grid loaded].
        /// </summary>
        /// <param name="obj">The object.</param>
        private void OnGridLoaded(object obj)
        {
            StationGrid = obj as Grid;
            int stationCount = 2;
            const short Columns = 2;
            this.StationGrid.Children.Clear();
            int rowCnt = stationCount / Columns;
            RowDefinition[] rows = new RowDefinition[rowCnt];
            ColumnDefinition[] columns = new ColumnDefinition[Columns];
            for (short rwcnt = 0; rwcnt < rows.Count(); rwcnt++)
            {
                rows[rwcnt] = new RowDefinition();
                this.StationGrid.RowDefinitions.Add(rows[rwcnt]);
                rows[rwcnt].Height = GridLength.Auto;
                rows[rwcnt].MinHeight = 300;
            }
            for (short clcnt = 0; clcnt < columns.Count(); clcnt++)
            {
                columns[clcnt] = new ColumnDefinition();
                this.StationGrid.ColumnDefinitions.Add(columns[clcnt]);
                columns[clcnt].Width = GridLength.Auto;
                columns[clcnt].MinWidth = 200;
            }
            short currentStationCount = 1;
            for (int clcnt = 0; clcnt < columns.Count(); clcnt++)
            {
                if (stationCount <= 0)
                {
                    break;
                }
                for (short rwcnt = 0; rwcnt < rows.Count(); rwcnt++)
                {
                    if (stationCount > 0)
                    {
                        ContentControl cnt = new ContentControl() { Width = double.NaN };
                        cnt = (ContentControl)GetView<ITextBoxControlViewModel>();
                        cnt.Name = "Station" + currentStationCount;
                        cnt.Tag = currentStationCount;
                        Grid.SetRow(cnt, rwcnt);
                        Grid.SetColumn(cnt, clcnt);
                        this.StationGrid.Children.Add(cnt);
                        stationCount--;
                        currentStationCount++;
                    }
                    else
                    {
                        break;
                    }
                }
            }
        }

        /// <summary>
        /// Ons the start script command.
        /// </summary>
        /// <param name="obj">The object.</param>
        private void onStartScriptCommand(object obj)
        {
            textBoxCnt = (ITextBoxControlViewModel)((ContentControl)StationGrid.Children.OfType<ContentControl>().FirstOrDefault(x => Convert.ToInt16(x.Tag) == 1)).DataContext;
            textBoxCnt.CallMethods();
        }
    }
}
