﻿using DataContextDemo.Common;
using StructureMap;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Threading;

namespace DatacontextDemo.ViewModel
{
    public class TextBoxControlViewModel : BaseViewModel, ITextBoxControlViewModel
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TextBoxControlViewModel"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        /// <param name="container">The container.</param>
        public TextBoxControlViewModel(ITextBoxControlView view, StructureMap.IContainer container)
            : base(view, container)
        {

        }
       
        /// <summary>
        /// Gets or sets the text output.
        /// </summary>
        /// <value>
        /// The text output.
        /// </value>
        public string TextOutput { get; set; }

        /// <summary>
        /// Gets or sets the _main window.
        /// </summary>
        /// <value>
        /// The _main window.
        /// </value>
        public IMainWindowViewModel _mainWindow { get; set; }
        
        /// <summary>
        /// Gets or sets the text count.
        /// </summary>
        /// <value>
        /// The text count.
        /// </value>
        public ITextBoxControlViewModel textCnt { get; set; }
       
        /// <summary>
        /// The _process
        /// </summary>
        public Process _process1 { get; set; }
      
        /// <summary>
        /// Gets or sets the _process2.
        /// </summary>
        /// <value>
        /// The _process2.
        /// </value>
        public Process _process2 { get; set; }
      
        /// <summary>
        /// Property TestStationGrid of ObservableCollection of ContentControl type
        /// </summary>
        public string temp { get; set; }

        /// <summary>
        /// Calls the methods.
        /// </summary>
        public void CallMethods()
        {
            CallMethodsAsync();
        }
      
        /// <summary>
        /// Calls the methods.
        /// </summary>
        public async void CallMethodsAsync()
        {
            await RunStations();
        }

        /// <summary>
        /// Runs the methods.
        /// </summary>
        /// <returns></returns>
        private async Task<string> RunStations()
        {

            await Task.WhenAny(
                Task.Run(() => FirstStation()),
                Task.Run(() => SecondStation())
                );
            return string.Empty;
        }
      
        /// <summary>
        /// Firsts the station.
        /// </summary>
        private void FirstStation()
        {
            string FileName = @"C:\Python27\python.exe";
            string Arguments = @"E:\Test.py";
            _process1 = new Process
            {
                EnableRaisingEvents = true,
                StartInfo =
                {
                    FileName = FileName,
                    Arguments = Arguments,
                    CreateNoWindow = true,
                    RedirectStandardError = true,
                    RedirectStandardOutput = true,
                    RedirectStandardInput = true,
                    UseShellExecute = false,
                    LoadUserProfile = true
                },
            };
            _process1.OutputDataReceived += OnOutputLineReceived;
            _process1.Start();
            Application.Current.Dispatcher.Invoke(
              DispatcherPriority.Send,
              new Action(
                  delegate()
                  {
                      _process1.BeginOutputReadLine();
                  }));
        }

        /// <summary>
        /// Seconds the station.
        /// </summary>
        private void SecondStation()
        {
            string FileName = @"C:\Python27\python.exe";
            string Arguments = @"E:\Test.py";
            _process2 = new Process
            {
                EnableRaisingEvents = true,
                StartInfo =
                {
                    FileName = FileName,
                    Arguments = Arguments,
                    CreateNoWindow = true,
                    RedirectStandardError = true,
                    RedirectStandardOutput = true,
                    RedirectStandardInput = true,
                    UseShellExecute = false,
                    LoadUserProfile = true
                },
            };
            _process2.OutputDataReceived += OnOutputLineReceived;
            _process2.Start();
            Application.Current.Dispatcher.Invoke(
              DispatcherPriority.Send,
              new Action(
                  delegate()
                  {
                      _process2.BeginOutputReadLine();
                  }));
        }

        /// <summary>
        /// Called when [output line received].
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="DataReceivedEventArgs"/> instance containing the event data.</param>
        public void OnOutputLineReceived(object sender, DataReceivedEventArgs e)
        {
            int StationNo;
            Process p = sender as Process;
            if (_mainWindow == null)
                _mainWindow = ObjectFactory.GetInstance<IMainWindowViewModel>();
            if (e.Data != null)
            {
                Application.Current.Dispatcher.Invoke(
              DispatcherPriority.Send,
              new Action(
                  delegate()
                  {
                      if (_process1.Id == p.Id)
                          StationNo = 1;
                      else
                          StationNo = 2;
                      if (StationNo > 0)
                      {
                          textCnt = (ITextBoxControlViewModel)((ContentControl)_mainWindow.StationGrid.Children.OfType<ContentControl>().FirstOrDefault(x => Convert.ToInt16(x.Tag) == StationNo)).DataContext;
                          temp = textCnt.TextOutput;
                          textCnt.TextOutput = temp + e.Data + "\n";
                      }
                  }));
            }
        }
    }
}
